@@ -5,6 +5,7 @@ from time import gmtime, strftime
 from akinaka_update.commands import update as update_commands
 from akinaka_cleanup.commands import cleanup as cleanup_commands
 from akinaka_rds.commands import copy as copy_commands
+from akinaka_reporting.commands import billing as billing_commands
 
 @click.group()
 def cli():
@@ -13,5 +14,6 @@ def cli():
 cli.add_command(update_commands)
 cli.add_command(cleanup_commands)
 cli.add_command(copy_commands)
+cli.add_command(billing_commands)
 
 cli()
